#!/bin/bash

######################################################
# Manual preparation before running this...
#
# SAVE ORIGINAL /usr/local AND MOVE IT OUT OF THE WAY
# mv /usr/local /usr/local.save
#
# 
# Install Ghostscript. The non-binaries will become part of this package
# but the binary will be replaced by separately compiled binaries
# Don't install the Ghostscript fonts; the script below will supply them.
#
######################################################

# We're going to run this in the MacTeXDVD working directory...
WORK=`pwd`

if [[ ! -x /usr/local/bin/gs ]]; then
	echo "### error: Ghostscript is missing"
	exit 1
fi

echo "Removing old file tree at ${WORK}/root"
rm -rf ${WORK}/root

# Copy everything from /usr/local into our root
echo "Collecting files from /usr/local"
mkdir -p ${WORK}/root/usr/local
cp -pRf /usr/local/bin ${WORK}/root/usr/local/bin
cp -pRf /usr/local/share ${WORK}/root/usr/local/share

# Deal with TeX fonts

cp ${WORK}/Bruno-TeXLive/Fontmap.cmr ${WORK}/root/usr/local/share/ghostscript/9.18/Resource/Init/Fontmap.cmr
cp ${WORK}/Bruno-TeXLive/Fontmap ${WORK}/root/usr/local/share/ghostscript/9.18/Resource/Init/Fontmap
cp ${WORK}/Bruno-TeXLive/Fontmap.MacTeX ${WORK}/root/usr/local/share/ghostscript/9.18/Resource/Init/Fontmap.MacTeX
cp -pRf ${WORK}/Bruno-TeXLive/fonts/*.pfb ${WORK}/root/usr/local/share/ghostscript/9.18/Resource/Font



# Bruno Voisin's Final Take, May 3

FILES1=${WORK}/Bruno-Japan/Font/*
for file in $FILES1
do
	cp -pRf $file ${WORK}/root/usr/local/share/ghostscript/9.18/Resource/Font 
done

FILES2=${WORK}/Bruno-Japan/CIDFont/*
for file in $FILES2
do
	cp -pRf $file ${WORK}/root/usr/local/share/ghostscript/9.18/Resource/CIDFont 
done

FILES3=${WORK}/Bruno-Japan/CIDFSubst/*
for file in $FILES3
do
	cp -pRf $file ${WORK}/root/usr/local/share/ghostscript/9.18/Resource/CIDFSubst
done

FILES4=${WORK}/Bruno-Japan/Init/*
for file in $FILES4
do
	cp -pRf $file ${WORK}/root/usr/local/share/ghostscript/9.18/Resource/Init
done


# Replace gs binary with binaries compiled on various platforms; active program determined by postinstall script

rm ${WORK}/root/usr/local/bin/gs
cp ${WORK}/Binaries/10.5/gs-noX11 ${WORK}/root/usr/local/bin/gs-noX11
cp ${WORK}/Binaries/10.5/gs-X11 ${WORK}/root/usr/local/bin/gs-X11
cp ${WORK}/Binaries/10.6/gs-X11-64Bit ${WORK}/root/usr/local/bin/gs-X11-64Bit
cp ${WORK}/Binaries/10.6/gs-noX11-64Bit ${WORK}/root/usr/local/bin/gs-noX11-64Bit
cp ${WORK}/Binaries/ElCapitan/gs-X11-ElCapitan ${WORK}/root/usr/local/bin/gs-X11-ElCapitan
cp ${WORK}/Binaries/ElCapitan/gs-noX11-ElCapitan ${WORK}/root/usr/local/bin/gs-noX11-ElCapitan

# chmod
echo "Changing permissions"
chmod -R a+r ${WORK}/root/usr
chown -R root  ${WORK}/root/usr
chgrp -R wheel  ${WORK}/root/usr

chmod 755 ${WORK}/root/usr
chgrp wheel ${WORK}/root/usr


